pub struct CheckpointStore { /* private fields */ }Implementations
Sourceimpl CheckpointStore
impl CheckpointStore
pub fn new(path: &Path, pruner_watermarks: Arc<PrunerWatermarks>) -> Arc<Self>
pub fn new_for_tests() -> Arc<Self>
pub fn new_for_db_checkpoint_handler(path: &Path) -> Arc<Self>
pub fn set_binary_version(&self, version: &str)
pub fn open_readonly(path: &Path) -> CheckpointStoreTablesReadOnly
pub fn insert_genesis_checkpoint( &self, checkpoint: VerifiedCheckpoint, contents: CheckpointContents, epoch_store: &AuthorityPerEpochStore, )
pub fn get_checkpoint_by_digest( &self, digest: &CheckpointDigest, ) -> Result<Option<VerifiedCheckpoint>, TypedStoreError>
pub fn get_checkpoint_by_sequence_number( &self, sequence_number: CheckpointSequenceNumber, ) -> Result<Option<VerifiedCheckpoint>, TypedStoreError>
pub fn get_locally_computed_checkpoint( &self, sequence_number: CheckpointSequenceNumber, ) -> Result<Option<CheckpointSummary>, TypedStoreError>
pub fn multi_get_locally_computed_checkpoints( &self, sequence_numbers: &[CheckpointSequenceNumber], ) -> Result<Vec<Option<CheckpointSummary>>, TypedStoreError>
pub fn get_sequence_number_by_contents_digest( &self, digest: &CheckpointContentsDigest, ) -> Result<Option<CheckpointSequenceNumber>, TypedStoreError>
pub fn delete_contents_digest_sequence_number_mapping( &self, digest: &CheckpointContentsDigest, ) -> Result<(), TypedStoreError>
pub fn get_latest_certified_checkpoint( &self, ) -> Result<Option<VerifiedCheckpoint>, TypedStoreError>
pub fn get_latest_locally_computed_checkpoint( &self, ) -> Result<Option<CheckpointSummary>, TypedStoreError>
pub fn multi_get_checkpoint_by_sequence_number( &self, sequence_numbers: &[CheckpointSequenceNumber], ) -> Result<Vec<Option<VerifiedCheckpoint>>, TypedStoreError>
pub fn multi_get_checkpoint_content( &self, contents_digest: &[CheckpointContentsDigest], ) -> Result<Vec<Option<CheckpointContents>>, TypedStoreError>
pub fn get_highest_verified_checkpoint( &self, ) -> Result<Option<VerifiedCheckpoint>, TypedStoreError>
pub fn get_highest_synced_checkpoint( &self, ) -> Result<Option<VerifiedCheckpoint>, TypedStoreError>
pub fn get_highest_synced_checkpoint_seq_number( &self, ) -> Result<Option<CheckpointSequenceNumber>, TypedStoreError>
pub fn get_highest_executed_checkpoint_seq_number( &self, ) -> Result<Option<CheckpointSequenceNumber>, TypedStoreError>
pub fn get_highest_executed_checkpoint( &self, ) -> Result<Option<VerifiedCheckpoint>, TypedStoreError>
pub fn get_highest_pruned_checkpoint_seq_number( &self, ) -> Result<Option<CheckpointSequenceNumber>, TypedStoreError>
pub fn get_checkpoint_contents( &self, digest: &CheckpointContentsDigest, ) -> Result<Option<CheckpointContents>, TypedStoreError>
pub fn get_full_checkpoint_contents_by_sequence_number( &self, seq: CheckpointSequenceNumber, ) -> Result<Option<VersionedFullCheckpointContents>, TypedStoreError>
pub fn clear_locally_computed_checkpoints_from( &self, from_seq: CheckpointSequenceNumber, ) -> SuiResult
pub fn insert_certified_checkpoint( &self, checkpoint: &VerifiedCheckpoint, ) -> Result<(), TypedStoreError>
pub fn insert_verified_checkpoint( &self, checkpoint: &VerifiedCheckpoint, ) -> Result<(), TypedStoreError>
pub fn update_highest_verified_checkpoint( &self, checkpoint: &VerifiedCheckpoint, ) -> Result<(), TypedStoreError>
pub fn update_highest_synced_checkpoint( &self, checkpoint: &VerifiedCheckpoint, ) -> Result<(), TypedStoreError>
pub async fn notify_read_synced_checkpoint( &self, seq: CheckpointSequenceNumber, ) -> VerifiedCheckpoint
pub async fn notify_read_executed_checkpoint( &self, seq: CheckpointSequenceNumber, ) -> VerifiedCheckpoint
pub fn update_highest_executed_checkpoint( &self, checkpoint: &VerifiedCheckpoint, ) -> Result<(), TypedStoreError>
pub fn update_highest_pruned_checkpoint( &self, checkpoint: &VerifiedCheckpoint, ) -> Result<(), TypedStoreError>
Sourcepub fn set_highest_executed_checkpoint_subtle(
&self,
checkpoint: &VerifiedCheckpoint,
) -> Result<(), TypedStoreError>
pub fn set_highest_executed_checkpoint_subtle( &self, checkpoint: &VerifiedCheckpoint, ) -> Result<(), TypedStoreError>
Sets highest executed checkpoint to any value.
WARNING: This method is very subtle and can corrupt the database if used incorrectly. It should only be used in one-off cases or tests after fully understanding the risk.
pub fn insert_checkpoint_contents( &self, contents: CheckpointContents, ) -> Result<(), TypedStoreError>
pub fn insert_verified_checkpoint_contents( &self, checkpoint: &VerifiedCheckpoint, full_contents: VerifiedCheckpointContents, ) -> Result<(), TypedStoreError>
pub fn delete_full_checkpoint_contents( &self, seq: CheckpointSequenceNumber, ) -> Result<(), TypedStoreError>
pub fn get_epoch_last_checkpoint( &self, epoch_id: EpochId, ) -> SuiResult<Option<VerifiedCheckpoint>>
pub fn get_epoch_last_checkpoint_seq_number( &self, epoch_id: EpochId, ) -> SuiResult<Option<CheckpointSequenceNumber>>
Sourcepub fn get_epoch_first_checkpoint_seq(
&self,
epoch: EpochId,
) -> SuiResult<Option<CheckpointSequenceNumber>>
pub fn get_epoch_first_checkpoint_seq( &self, epoch: EpochId, ) -> SuiResult<Option<CheckpointSequenceNumber>>
Returns the sequence number of the first checkpoint in the given epoch. For epoch 0 this is always 0; for epoch N > 0 it is last_checkpoint(N-1) + 1.
Sourcepub fn list_checkpoints_from_seq(
&self,
start: Option<CheckpointSequenceNumber>,
limit: usize,
) -> Result<Vec<(CheckpointSequenceNumber, VerifiedCheckpoint)>, TypedStoreError>
pub fn list_checkpoints_from_seq( &self, start: Option<CheckpointSequenceNumber>, limit: usize, ) -> Result<Vec<(CheckpointSequenceNumber, VerifiedCheckpoint)>, TypedStoreError>
Iterate certified checkpoints starting at start (inclusive), up to limit.
Sourcepub fn list_epoch_last_checkpoints(
&self,
start: Option<EpochId>,
limit: usize,
) -> Result<Vec<(EpochId, CheckpointSequenceNumber)>, TypedStoreError>
pub fn list_epoch_last_checkpoints( &self, start: Option<EpochId>, limit: usize, ) -> Result<Vec<(EpochId, CheckpointSequenceNumber)>, TypedStoreError>
Iterate epoch→last-checkpoint-seq entries starting at start epoch, up to limit.
Sourcepub fn list_checkpoint_digests(
&self,
start: Option<CheckpointDigest>,
limit: usize,
) -> Result<Vec<CheckpointDigest>, TypedStoreError>
pub fn list_checkpoint_digests( &self, start: Option<CheckpointDigest>, limit: usize, ) -> Result<Vec<CheckpointDigest>, TypedStoreError>
Iterate checkpoint digests from checkpoint_by_digest, starting at start, up to limit.
Sourcepub fn list_checkpoint_contents_digests(
&self,
start: Option<CheckpointContentsDigest>,
limit: usize,
) -> Result<Vec<CheckpointContentsDigest>, TypedStoreError>
pub fn list_checkpoint_contents_digests( &self, start: Option<CheckpointContentsDigest>, limit: usize, ) -> Result<Vec<CheckpointContentsDigest>, TypedStoreError>
Iterate checkpoint contents digests, starting at start, up to limit.
Sourcepub fn list_epoch_checkpoints(
&self,
epoch: EpochId,
start_seq: Option<CheckpointSequenceNumber>,
limit: usize,
) -> Result<Vec<(CheckpointSequenceNumber, VerifiedCheckpoint)>, TypedStoreError>
pub fn list_epoch_checkpoints( &self, epoch: EpochId, start_seq: Option<CheckpointSequenceNumber>, limit: usize, ) -> Result<Vec<(CheckpointSequenceNumber, VerifiedCheckpoint)>, TypedStoreError>
Iterate certified checkpoints belonging to epoch, starting at start_seq, up to limit.
pub fn insert_epoch_last_checkpoint( &self, epoch_id: EpochId, checkpoint: &VerifiedCheckpoint, ) -> SuiResult
pub fn get_epoch_state_commitments( &self, epoch: EpochId, ) -> SuiResult<Option<Vec<CheckpointCommitment>>>
Sourcepub fn get_epoch_stats(
&self,
epoch: EpochId,
last_checkpoint: &CheckpointSummary,
) -> Option<EpochStats>
pub fn get_epoch_stats( &self, epoch: EpochId, last_checkpoint: &CheckpointSummary, ) -> Option<EpochStats>
Given the epoch ID, and the last checkpoint of the epoch, derive a few statistics of the epoch.
pub fn checkpoint_db(&self, path: &Path) -> SuiResult
pub fn delete_highest_executed_checkpoint_test_only( &self, ) -> Result<(), TypedStoreError>
pub fn reset_db_for_execution_since_genesis(&self) -> SuiResult
pub fn record_checkpoint_fork_detected( &self, checkpoint_seq: CheckpointSequenceNumber, checkpoint_digest: CheckpointDigest, certified_checkpoint_digest: Option<CheckpointDigest>, ) -> Result<(), TypedStoreError>
pub fn get_checkpoint_fork_detected( &self, ) -> Result<Option<CheckpointForkInfo>, TypedStoreError>
pub fn clear_checkpoint_fork_detected(&self) -> Result<(), TypedStoreError>
pub fn record_transaction_fork_detected( &self, tx_digest: TransactionDigest, expected_effects_digest: TransactionEffectsDigest, actual_effects_digest: TransactionEffectsDigest, certified_checkpoint_seq: Option<CheckpointSequenceNumber>, ) -> Result<(), TypedStoreError>
pub fn get_transaction_fork_detected( &self, ) -> Result<Option<TransactionForkInfo>, TypedStoreError>
pub fn clear_transaction_fork_detected(&self) -> Result<(), TypedStoreError>