pub struct CheckpointStoreTablesReadOnly {
pub checkpoint_content: DBMap<CheckpointContentsDigest, CheckpointContents>,
pub checkpoint_sequence_by_contents_digest: DBMap<CheckpointContentsDigest, CheckpointSequenceNumber>,
pub full_checkpoint_content: DBMap<CheckpointSequenceNumber, FullCheckpointContents>,
pub certified_checkpoints: DBMap<CheckpointSequenceNumber, TrustedCheckpoint>,
pub checkpoint_by_digest: DBMap<CheckpointDigest, TrustedCheckpoint>,
pub locally_computed_checkpoints: DBMap<CheckpointSequenceNumber, CheckpointSummary>,
pub epoch_last_checkpoint_map: DBMap<EpochId, CheckpointSequenceNumber>,
pub watermarks: DBMap<CheckpointWatermark, (CheckpointSequenceNumber, CheckpointDigest)>,
pub transaction_fork_detected: DBMap<u8, (TransactionDigest, TransactionEffectsDigest, TransactionEffectsDigest)>,
pub full_checkpoint_content_v2: DBMap<CheckpointSequenceNumber, VersionedFullCheckpointContents>,
}Fields
checkpoint_content: DBMap<CheckpointContentsDigest, CheckpointContents>checkpoint_sequence_by_contents_digest: DBMap<CheckpointContentsDigest, CheckpointSequenceNumber>full_checkpoint_content: DBMap<CheckpointSequenceNumber, FullCheckpointContents>certified_checkpoints: DBMap<CheckpointSequenceNumber, TrustedCheckpoint>checkpoint_by_digest: DBMap<CheckpointDigest, TrustedCheckpoint>locally_computed_checkpoints: DBMap<CheckpointSequenceNumber, CheckpointSummary>epoch_last_checkpoint_map: DBMap<EpochId, CheckpointSequenceNumber>watermarks: DBMap<CheckpointWatermark, (CheckpointSequenceNumber, CheckpointDigest)>transaction_fork_detected: DBMap<u8, (TransactionDigest, TransactionEffectsDigest, TransactionEffectsDigest)>full_checkpoint_content_v2: DBMap<CheckpointSequenceNumber, VersionedFullCheckpointContents>Implementations
Sourceimpl CheckpointStoreTablesReadOnly
impl CheckpointStoreTablesReadOnly
Sourcepub fn open_tables_read_only(
primary_path: PathBuf,
with_secondary_path: Option<PathBuf>,
metric_conf: MetricConf,
global_db_options_override: Option<Options>,
) -> Self
pub fn open_tables_read_only( primary_path: PathBuf, with_secondary_path: Option<PathBuf>, metric_conf: MetricConf, global_db_options_override: Option<Options>, ) -> Self
Open in read only mode. No limitation on number of processes to do this
Sourcepub fn dump(
&self,
cf_name: &str,
page_size: u16,
page_number: usize,
) -> Result<BTreeMap<String, String>>
pub fn dump( &self, cf_name: &str, page_size: u16, page_number: usize, ) -> Result<BTreeMap<String, String>>
Dump all key-value pairs in the page at the given table name
Tables must be opened in read only mode using open_tables_read_only
Sourcepub fn table_summary(&self, table_name: &str) -> Result<TableSummary>
pub fn table_summary(&self, table_name: &str) -> Result<TableSummary>
Get key value sizes from the db
Tables must be opened in read only mode using open_tables_read_only
pub fn describe_tables() -> BTreeMap<String, (String, String)>
Sourcepub fn try_catch_up_with_primary_all(&self) -> Result<()>
pub fn try_catch_up_with_primary_all(&self) -> Result<()>
Try catch up with primary for all tables. This can be a slow operation
Tables must be opened in read only mode using open_tables_read_only